Utils
=====

Submodules
----------

.. toctree::

   xbox.sg.utils.adapters
   xbox.sg.utils.events
   xbox.sg.utils.struct

Module contents
---------------

.. automodule:: xbox.sg.utils
    :members:
    :undoc-members:
    :show-inheritance:
